@@ -6,13 +6,25 @@ use warnings;
 use strict;
 use utf8;
 use Benchmark ':all';
+use FindBin '$Bin';
+
+# Just so I can use the latest versions
+
 use lib '/home/ben/projects/json-create/blib/lib';
 use lib '/home/ben/projects/json-create/blib/arch';
+
+# Contenders
+
 use JSON::Create 'create_json';
 use JSON::XS;
 use Cpanel::JSON::XS;
 
-use FindBin '$Bin';
+# Number of repetitions
+
+my $count = 400000;
+
+# ASCII string test
+
 my $stuff = {
     captain => 'planet',
     he => "'s",
@@ -28,9 +40,7 @@ my $stuff = {
     side => "Captain Planet!",
 };
 
-my $count = 400000;
-
-print "Comparing hash of ASCII strings...\n";
+header ("hash of ASCII strings");
 
 cmpthese (
     $count,
@@ -74,9 +84,14 @@ my $h2n = {
     x => 8_388_608,
     y => 16_777_216,
     z => 33_554_432,
+    A => 67_108_864,
+    B => 134_217_728,
+    C => 268_435_456,
+    D => 536_870_912,
+    E => 1_073_741_824,
 };
 
-print "Comparing hash of integers...\n";
+header ("hash of integers");
 
 cmpthese (
     $count,
@@ -107,7 +122,7 @@ my %unihash = (
 );
 
 
-print "Comparing hash of Unicode strings...\n";
+header ("hash of Unicode strings");
 
 cmpthese (
     $count,
@@ -124,3 +139,28 @@ cmpthese (
     },    
 );
 
+header ("array of floats");
+
+my $floats = [1.0e-10, 0.1, 1.1, 9e9, 3.141592653,-1.0e-20,-9e19,];
+
+cmpthese (
+    $count,
+    {
+	'JC' => sub {
+	    my $x = JSON::Create::create_json ($floats);
+	},
+	'JX' => sub {
+	    my $x = JSON::XS::encode_json ($floats);
+	},
+	'CJX' => sub {
+	    my $x = Cpanel::JSON::XS::encode_json ($floats);
+	},
+    },    
+);
+exit;
+
+sub header
+{
+    my ($head) = @_;
+    print "\nComparing $head...\n\n";
+}
